% Calculates optimal individual utility, substitutes it into the utility
% function and scales it with the threatpoint scaling factor

%{
  Param:
   -thi: vector of type i = {1, 2}'s theta (delta, alpha, beta) natural
   parameterizations (tau not needed here)
   -x: matrix of covariates with dimension N x (K - 1) / 2
   -k: vector of type i's error draws of length N * NREPS
   -f: scalar threatpoint scaling factor
   -rho
%}

%{
  Return:           
   -opt: vector of optimal individual utilites of length N * NREPS
%}


function [opt] = A(thi, fi, k, f, rho)
    % optimal retirment time calculated analytically, using Z_i functional
    % form assumption
    t = (k ./ fi) .^ (1 / thi(2));
    ztt = Ztilde(thi(2), t, rho);
    ert = exp(-rho .* t);
    % calculate scaled utility
    opt = f * Un(fi, k, rho, ztt, ert);
end