% The function takes t, rho and tau as input arguments and calculates Z2 tilde

%{ 
  Param: 
   -alpha: scalar parameter of Z-tilde
   -t: scalar retirement time
%}

% f is the result, the scalar Z-tilde value

% example: f = Ztilde2(t, rho, tau)

function [f] = Ztilde2bo(t, rho, tau)
g1 = bsxfun(@gt,t, tau);
g2 = bsxfun(@gt,t, tau+0.5);
g3 = bsxfun(@gt,t, tau+1);

r1 = 1 - g1;
r2 = g1 .* (1 - g2);
r3 = g2 .* (1 - g3);
r4 = g3;

rtaup0=rho*tau;
rtaupH=rho*(tau + 0.5);
rtaup1=rho*(tau + 1);
rt=rho*t;
ert=exp(-rt);
ertau1=exp(-rtaup1);
ertauH=exp(-rtaupH);
ertau0=exp(-rtaup0);
% up3taup1=upperinc(3, rtaup1);
up3taup1=2*ertau1.*(1+rtaup1+(rtaup1.^2)/2);
% up2taup1=upperinc(2, rtaup1);
up2taup1=ertau1.*(1+rtaup1);

% up3tauH=upperinc(3, rtaupH);
up3tauH=2*ertauH.*(1+rtaupH+(rtaupH.^2)/2);
% up2tauH=upperinc(2, rtaupH);
up2tauH=ertauH.*(1+rtaupH);

% up3taup0=upperinc(3, rtaup0);
up3taup0=2*ertau0.*(1+rtaup0+(rtaup0.^2)/2);
% up2taup0=upperinc(2, rtaup0);
up2taup0=ertau0.*(1+rtaup0);

% up3t0=upperinc(3, rt);
up3t0=2*ert.*(1+rt+(rt.^2)/2);
% up2t0=upperinc(2, rt);
up2t0=ert.*(1+rt);



f4 = (1 / rho) * ert;
f = (1 / rho) * ertau1;
f3 = f - 2 * (1/rho)^3 * (up3t0 - up3taup1)...
            + 4*(tau + 1) * (1/rho)^2 .* (up2t0 - up2taup1)...
            + (1 - 2*(1 + tau).^2) * (1/rho) .* (ert - ertau1);
f2 = f - 2 * (1/rho)^3 * (up3tauH - up3taup1)...
            + 4*(tau + 1) * (1/rho)^2 .* (up2tauH - up2taup1)...
            + (1 - 2*(1 + tau).^2) * (1/rho) .* (ertauH - ertau1)...
            + 2 * (1/rho)^3 * (up3t0 - up3tauH)...
            - 4 * tau * (1/rho)^2 .* (up2t0 - up2tauH)...
            + 2 * tau.^2 * (1/rho) .* (ert - ertauH);
f1 = f - 2 * (1/rho)^3 * (up3tauH - up3taup1)...
            + 4*(tau + 1) * (1/rho)^2 .* (up2tauH - up2taup1)...
            + (1 - 2*(1 + tau).^2) * (1/rho) .* (ertauH - ertau1)...
            + 2 * (1/rho)^3 * (up3taup0 - up3tauH)...
            - 4 * tau * (1/rho)^2 .* (up2taup0 - up2tauH)...
            + 2 * tau.^2 * (1/rho) .* (ertau0 - ertauH);
f = r1.*f1 + r2.*f2 + r3.*f3 + r4.*f4;


end

