% major loop in rettimes
% calculates optimal retirement times for each one of the t1 < t2, t2 < t1
% and t1 = t2 scenarios

% inputs: 
% b2a, b1b, bc: bounds for the possible values of the optimum in
% each scenario
% t1a, t2b: retirement time that is given in the first two scenarios
% k1, k2, x1, fi2, th1, th2, tau1, tau2, rho, f

function [t2a, t1b, tc] = loopT2Jumps(b2a, b1b, bc, t1a, t2b, k1, k2, fi1, fi2, th1, th2, tau1, tau2, rho, f)

% initialize maxx
maxx = 1;

%%% continue with the loop as long as not all the interval of possible optimum values are 
%%% all small enough

ert1a = exp(-rho .* t1a);
ztt1a = ZtildeT2Jumps(th1(2), t1a, rho, tau1, th1(3:4));
ert2b = exp(-rho .* t2b);
ztt2b = ZtildeT2Jumps(th2(2), t2b, rho, tau2, th2(3:4));
fij1a1 = fi1 .* (1-th2(1));
fij1a2 = th2(1) .* fi2;
fij2b1 = fi2 .* (1-th1(1));
fij2b2 = th1(1) .* fi1;
fij3c = th1(1) .* fi2;
A2 = AT(th2, fi2, k2, f, rho, tau2);
A1 = AT(th1, fi1, k1, f, rho, tau1);

iter=0;
while ((maxx > 0.0001)&&(iter<1000))
% MADE A CORRECTION HERE max VS maxx
iter=iter+1; 
    %%%% t1 < t2. Know t1, search for t2 %%%
    % find the midpoint
    mida = (b2a(:,1) + b2a(:,2))/2;
    % difference between midpoint and endpoint of the interval
    inca = (b2a(:,2) - mida);
    % calculate the derivative for the Nash bargaining problem at the mid point
    nasha = nashseqfocT2Jumps(mida, k2, k1, th2, th1, fi2, fi1, tau2, tau1, rho, ert1a, ztt1a, fij1a1, fij1a2, A2, A1);
    % determine the sign of the derivative
    eea1 = ge(nasha, 0);
    eea2 = ge(0, nasha);
%WAS     eea1 = gt(nasha, 0);
%WAS     eea2 = gt(0, nasha);
    % halve the size of the interval of the possible optimum values in the direction
    % corresponding to the sign of the derivative
    b2a(:,1) = b2a(:,1) + eea1 .* inca;
    b2a(:,2) = b2a(:,2) - eea2 .* inca;

    %%% t2 < t1. Know t2, search for t1 %%%
    % find the midpoint
    midb = (b1b(:,1) + b1b(:,2))/2;
    % difference between midpoint and endpoint of the interval
    incb = (b1b(:,2) - midb);
    % calculate the derivative for the Nash bargaining problem at the mid point
    nashb = nashseqfocT2Jumps(midb, k1, k2, th1, th2, fi1, fi2, tau1, tau2, rho, ert2b, ztt2b, fij2b1, fij2b2, A1, A2);
    % determine the sign of the derivative
    eeb1 = ge(nashb, 0);
    eeb2 = ge(0, nashb);
%WAS     eeb1 = gt(nasha, 0);
%WAS     eeb2 = gt(0, nasha);
    % halve the size of the interval of the possible optimum values in the direction
    % corresponding to the sign of the derivative
    b1b(:,1) = b1b(:,1) + eeb1 .* incb;
    b1b(:,2) = b1b(:,2) - eeb2 .* incb;
%WAS b2b(:,2) = b2b(:,2) - eeb2 .* incb;

    %%% t1 = t2 %%%
    % find the midpoint
    midc = (bc(:,1) + bc(:,2))/2;
    ertc = exp(-rho .* midc);
    % calculate individual utilities at the midpoint
    ztt1 = ZtildeT2Jumps(th1(2), midc, rho, tau1, th1(3:4));
    ztt2 = ZtildeT2Jumps(th2(2), midc, rho, tau2, th2(3:4));
    u1 = Ut(th1, fi1, k1, rho, ztt1, ertc);
    u2 = Ut(th2, fi2, k2, rho, ztt2, ertc);
%WAS     u1 = U(thi1, x1, k1, midc, midc, true, rho);
%WAS     u2 = U(thi2, x2, k2, midc, midc, true, rho);

%thi corrected to th
    % determine whether individual utilities are greater than threatpoint
    pos1 = u1 > A1;
    pos2 = u2 > A2;
    % calculate the derivative for the Nash bargaining problem at the mid point
    nashs = nashsimfocT2Jumps(midc, k1, k2, th1, th2, tau1, tau2, rho, ztt1, ztt2, ertc, fij2b2, fij3c, fij1a2, A2, A1);
    % calculate individual derivatives at the mid point
    indiv1 = indfocT2Jumps(midc, k1, th1, fi1, ertc, tau1);
    indiv2 = indfocT2Jumps(midc, k2, th2, fi2, ertc, tau2);
    % determine the sign of the derivative
    eec = (nashs > 0) - (nashs < 0);
    % determine the sign of the individual derivatives
    du1c(:,1) = indiv1 < 0;
    du1c(:,2) = indiv2 < 0;
    du2c(:,1) = indiv1 > 0;
    du2c(:,2) = indiv2 > 0;
    duc(:,1) = du2c(:,1) - du1c(:,1);
    duc(:,2) = du2c(:,2) - du1c(:,2);
    % determine which half of the interval contains the optimal t value
    % (if both individual utilities are greater than the threat point, then move
    % in the direction of the sign of the joint derivative, if not, move in the
    % direction that the one whose threat point is still greater requires it)
    einc = pos1 .* pos2 .* eec + pos1 .* (1 - pos2) .* duc(:,2) ...
        + (1 - pos1) .* pos2 .* duc(:,1) + (1 - pos1) .* (1 - pos2) ...
        .* (du2c(:,1) .* du2c(:,2) - du1c(:,1) .* du1c(:,2));
    einc = einc > 0;
    % difference between midpoint and endpoint of the interval
    incc = (bc(:,2) - midc);
    % halve the size of the interval of the possible optimum values in the direction
    % calculated above
    bc = bc + [einc.*incc (einc-1).*incc];
    
    % loop condition, check whether all the intervals are small enough already
    difff(:,1) = 2*(b2a(:,1) - b2a(:,2))./(b2a(:,1) + b2a(:,2));
    difff(:,2) = 2*(b1b(:,1) - b1b(:,2))./(b1b(:,1) + b1b(:,2));
    difff(:,3) = 2*(bc(:,1) - bc(:,2))./(bc(:,1) + bc(:,2));
    difff = abs(difff);
    maxx = max(difff);

    if iter>300
        'loooops'
        [maxx iter]
        save('debugdata','b2a', 'b1b', 'bc', 'fi1','fi2','th1','th2');
    end
    maxx=max(maxx);
end

    
% output the optimum solutions, the midpoints of each, at most 0.001 big, intervals
t2a = (b2a(:,1) + b2a(:,2))/2;
t1b = (b1b(:,1) + b1b(:,2))/2;
tc = (bc(:,1) + bc(:,2))/2;
end




