% olpsmle.m - performs PSMLE on ordered logit likelihood function
%
% Other m-files required: none
% Subfunctions: ol_psmle, ol_psmle_obj_foc, ol_psmle_soc
%
% C-files required: N/A
%
% Execute:        olpsmle
%
% Author: Andrew Semelhago
%
% email: andrewis@princeton.edu
%
% April 2015; Last revision: 2015-04-06
%
%------------- BEGIN CODE --------------

function ol
b = [1; .5; 2.5; 1];
x=[2 4 3; 1 5 7; 6 1 9];
u1=[.1231; .7412; .2318];
U1=-log(u1);
T1=U1.*exp(-x*(b(2:length(b))));
u2=[.1675; 0.5293; 0.9081];
U2=-log(u2);
T2=U2.*exp(-x*(b(2:length(b))));

[f, der] = ol_psmle_obj_foc(b, T1, T2, x)
derder = ol_psmle_soc(b, x)
ol_psmle(T1, T2, x)

%%%%%%%%%%%%%%%
% [ll1, der] = weibul_mle_obj_foc(b, T, ceni, x);
% 

end

function p = ol_psmle(t1, t2, x)
y = 0 * (t2 > t1 + 1) + (abs(t1 - t2) <= 1) + 2 * (t1 > t2 + 1);

d0 = y > 0;
d1 = y > 1;
bet1 = ((transpose(x) * x) ^ -1) * (transpose(x) * d0);
bet2 = ((transpose(x) * x) ^ -1) * (transpose(x) * d1);

p = cat(1, bet1, bet1(1) - bet2(1));
b = p;
converged = 0;

while not (converged)
    options = optimoptions(@fminunc,'Algorithm', 'quasi-newton', ...
        'GradObj', 'on', 'Display', 'off');
    
    f = @(beta)ol_psmle_obj_foc(beta, t1, t2, x);
    [p, fmax] = fminunc(f, b, options);
    converged = 1;
    
    b = p;
    h = 0.0001;
    
    for i = 1:length(p)
       pp = p;
       pp(i) = pp(i) + h;
       f1 = ol_psmle_obj_foc(pp, t1, t2, x);
       fprintf('1: f1: %d;  fmax: %d\n', -f1, fmax);
       if -f1 > fmax
           fmax = -f1;
           b = pp;
           converged = 0;
       end
       
       pp = p;
       pp(i) = pp(i) - h;
       f1 = ol_psmle_obj_foc(pp, t1, t2, x);
       fprintf('2: f1: %d;  fmax: %d\n', -f1, fmax);
       if -f1 > fmax
           fmax = -f1;
           b = pp;
           converged = 0;
       end
    end
end
end

function [f, der] = ol_psmle_obj_foc(beta, t1, t2, x)
if (isvector(x))
    n = length(x);
else
    n = size(x, 1);
end

y = 0 * (t2 > t1 + 1) + (abs(t1 - t2) <= 1) + 2 * (t1 > t2 + 1);
d0 = y > 0;
d1 = y > 1;
x0 = [x zeros(n, 1)];
x1 = [x (zeros(n, 1) + 1)];
xb0 = x0 * beta;
xb1 = x1 * beta;

f = dot(xb0, d0) + dot(xb1, d1) - sum(log(1 + exp(xb0))) - sum(log(1 + exp(xb1)));
f = -f / n;

df = transpose(zeros(n, 1) + 1) * (bsxfun(@times, d0 - Lambda(xb0), x0) + ...
    bsxfun(@times, d1 - Lambda(xb1), x1));

der = df / n;
end

function derder = ol_psmle_soc(beta, x)
if (isvector(x))
    n = length(x);
else
    n = size(x, 1);
end
x0 = [x zeros(n, 1)];
x1 = [x (zeros(n, 1) + 1)];
xb0 = x0 * beta;
xb1 = x1 * beta;

derder = -(transpose(bsxfun(@times, (1 - Lambda(xb0)) .* Lambda(xb0), x0)) * x0 + ...
    transpose(bsxfun(@times, (1 - Lambda(xb1)) .* Lambda(xb1), x1)) * x1);
end
function l = Lambda(x)
l = exp(x) ./ (1 + exp(x));
end

