%%Calculates parameters that maximize Weibul likelihood function%%

%{
Param:
ti: n x 1 vector of times
ceni: n x 1 vector of indicators (true if censoring occured)
xi: n x k matrix of data
%}

%{
Returns:
k x 1 vector of coefficient estimates
%}

function p = weibul_mle(ti, ceni, xi)
bet = -(transpose(xi) * xi)^-1 * (transpose(xi) * log(ti));
alp = 0.0;
p = cat(1, alp, bet);

b = p;
converged = 0;

while not(converged)
    options = optimoptions(@fminunc,'Algorithm', 'quasi-newton', ...
        'GradObj', 'on', 'Display', 'iter-detailed');

    f = @(beta)weibul_mle_obj_foc(beta, ti, ceni, xi);
    [p, fmax] = fminunc(f, b, options);
    fmax = -fmax;
    converged = 1;
    
    b = p;
    h = 0.001;
    
    for i = 1:length(p)
       pp = p;
       pp(i) = pp(i) + h;
       f1 = weibul_mle_obj_foc(pp, ti, ceni, xi);
       %fprintf('1: f1: %d;  fmax: %d\n', -f1, fmax);
       if -f1 > fmax
           fmax = -f1;
           b = pp;
           converged = 0;
       end
       
       pp = p;
       pp(i) = pp(i) - h;
       f1 = weibul_mle_obj_foc(pp, ti, ceni, xi);
       %fprintf('2: f1: %d;  fmax: %d\n', -f1, fmax);
       if -f1 > fmax
           fmax = -f1;
           b = pp;
           converged = 0;
       end
    end
end
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%