%%Calculates objective requiring maximization and FOC%%

%{
Param:
beta: k x 1 vector of estimated coefficients
ti: n x 1 vector of times
ceni: n x 1 vector of indicators (true if censoring occured)
xi: n x k matrix of data
%}

%{
Returns:
Objective function and its FOC
%}

function [ll, der] = weibul_mle_obj_foc(beta, ti, ceni, xi)
if (isvector(xi))
    n = length(xi);
else
    n = size(xi, 1);
end

%%% Start of Objective Calculation %%%
bet = beta(2:length(beta));
exb = exp(xi * bet);
tia = ti .^ exp(beta(1));
lti = log(ti);
alpha = exp(beta(1));

ll = ( ...
    sum((1 - ceni) .* (log(alpha) + (alpha - 1) .* log(ti) + ...
        xi * bet)) - sum(tia .* exb) ...
            );

% to maximise objective
ll = -ll / n;

%%% Start of FOC Calculation %%%

dL_dg = (sum((1 - ceni) .* (1 / alpha + lti)) ...
            - sum((tia) .* lti .* exb)) * alpha;
        
dL_db = ones(1, n) * (repmat(1 - ceni, 1, size(xi, 2)) .* xi) ...
                - ones(1, n) * (repmat(tia .* exb, 1, size(xi, 2)) .* xi);

der = - [dL_dg dL_db] / n;
end
