//=======/=========/=========/=========/=========/=========/=========/========/=========/=========/=========/=========/=========/========/========/========//
//
// 	Honore and de Paula: TIME VARIATION IN VARIABLES BEFORE RETIREMENT
//	This file generates the results referenced in the last paragraph from Section 5.
//
//=======/=========/=========/=========/=========/=========/=========/========/=========/=========/=========/=========/=========/========/========/========//

clear
clear matrix

set memory 500m
set more off

/// the dataset cpi.dta contains cpi data

use cpi.dta
sort interviewyrh interviewmonh

/// the dataset sp500.dta contains sp500 closing values (adjusted for splits, dividends) for the SP500

use sp500.dta
sort interviewyrh interviewmonh
merge m:1 interviewyrh interviewmonh using cpi, keepusing(cpi)
drop _merge*

/// deflates the sp500 index

gen lagcpi = cpi[_n-1]
gen lagsp500 = sp500[_n-1]
gen sp500factor = sp500/lagsp500*lagcpi/cpi
replace sp500factor = 1 if interviewyrh==1991 & interviewmonh==1
gen sp500real = exp(sum(ln(sp500factor)))
drop sp500factor lagcpi lagsp500

save realsp500.dta, replace

/// the dataset honoredepaula.dta is generated from unrestricteddataset063010.dta by hpdataprep.do.

use honoredepaula
sort interviewyrh interviewmonh
merge m:1 interviewyrh interviewmonh using realsp500, keepusing(sp500real)
drop _merge*

/// ageo marks the age of the oldest in the couple and husbando indicates whether the husband is the oldest.

gen ageo = max(ageh,agew)

keep if ageo>=60
drop if ageo>=.

/// drops observations where either husband or wife retired or were last interviewed before 60 yrs.-old

gen hhdobmh = min(dobmh,dobmw)
gen hhdobmw = min(dobmh,dobmw)
drop if (rretmh-hhdobmh<720 | rretmw-hhdobmw<720 | lastintmh-hhdobmh<720 | lastintmw-hhdobmw<720 | deathmh-hhdobmh<720 | deathmw-hhdobmw<720)

/// drops observations where interview is past retirement for both individuals

drop if (intmh>rretmh & intmw>rretmw)

/// keep only couples where both are in the labor force

keep if (rnotinlbrfh==0 & rnotinlbrfw==0)
count

/// keeps the variables that are important for the analysis

drop ageo ageh agew rretyrh rretyrw rretmonh rretmonw firstintyrh firstintyrw firstintyr firstintageh ///
	firstintagew lastintyrh lastintyrw lastintyr lastintageh lastintagew rretyrdif ///
	rretmondif agedifgroup interviewmonh interviewyrh rworkh cohorth rpartlyreth rretiredh ///
	interviewmonw interviewyrw rworkw rpartlyretw rretiredw rabmonthw rabyearw rabmonthh rabyearh ///
	cohortw interviewyr intmh intmw deathmoh deathmow deathyrh deathyrw

/// generates censoring time and drops observations for which it is missing.

gen censtimeh = min(lastintmh,deathmh)-hhdobmh-720
gen censtimew = min(lastintmw,deathmw)-hhdobmw-720

drop if (censtimeh==. | censtimew==.)

/// reshaping into long format
 	
gen financialwealthw = financialwealth
rename financialwealth financialwealthh
gen totalwealthw = totalwealth
rename totalwealth totalwealthh
gen agedifh = agedif
rename agedif agedifw
gen waveh = wave
rename wave wavew
gen sverygoodhealthh = rverygoodhealthw
gen sgoodhealthh = rgoodhealthw
gen spoorhealthh = rpoorhealthw
gen sverygoodhealthw = rverygoodhealthh
gen sgoodhealthw = rgoodhealthh
gen spoorhealthw = rpoorhealthh
gen spension1DCh = rpension1DCw
gen spension1DBh = rpension1DBw
gen spension1DCw = rpension1DCh
gen spension1DBw = rpension1DBh

sort hh wavew financialwealthw 
by hh: gen lagfinwealth = financialwealthw[_n-1] if wavew==wavew[_n-1]+1
by hh: gen lagsp500real = sp500real[_n-1] if wavew==wavew[_n-1]+1

gen finshock = (financialwealthw-lagfinwealth)/lagfinwealth

sum finshock if rretmh==rretmw
sum finshock if rretmh~=rretmw

gen finshocksp = (financialwealthw-lagfinwealth)*lagsp500real/(lagfinwealth*sp500real)

sum finshocksp if rretmh==rretmw
sum finshocksp if rretmh~=rretmw
 
xtset hh
xtsum rhealthinsurancew rhealthinsuranceh rverygoodhealthw ///
	rgoodhealthw rpoorhealthw rverygoodhealthh rgoodhealthh rpoorhealthh ///
	rtothealthexpenw rtothealthexpenh rpension1DCw rpension1DCh
xtsum rhealthinsurancew rhealthinsuranceh rverygoodhealthw ///
	rgoodhealthw rpoorhealthw rverygoodhealthh rgoodhealthh rpoorhealthh ///
	rtothealthexpenw rtothealthexpenh rpension1DCw rpension1DCh if rretmh==rretmw
xtsum rhealthinsurancew rhealthinsuranceh rverygoodhealthw ///
	rgoodhealthw rpoorhealthw rverygoodhealthh rgoodhealthh rpoorhealthh ///
	rtothealthexpenw rtothealthexpenh rpension1DCw rpension1DCh if rretmh~=rretmw

