//=======/=========/=========/=========/=========/=========/=========/========/=========/=========/=========/=========/=========/========/========/========//
//
// 	Honore and de Paula: TABLE 1 and DATA FOR MATLAB
//	This file generates the information in Table 1.  If the line "save hpdatamata, replace" is left uncommented, 
//  it also produces the data used by the Matlab files (once translated into Excel format).
//
//=======/=========/=========/=========/=========/=========/=========/========/=========/=========/=========/=========/=========/========/========/========//

clear
clear matrix

set memory 500m
set more off

use honoredepaula
count

/// ageo marks the age of the oldest in the couple and husbando indicates whether the husband is the oldest.

gen ageo = max(ageh,agew)

sort hh ageo wave
by hh: gen lagageo = ageo[_n-1] if wave==wave[_n-1]+1

keep if (lagageo<60 & ageo>=60)|(lagageo==. & ageo==60)
drop if ageo>=.
count

/// keep only couples where both are in the labor force

keep if (rnotinlbrfh==0 & rnotinlbrfw==0)

/// drops observations where either husband or wife retired or were last interviewed before 60 yrs.-old

gen hhdobmh = min(dobmh,dobmw)
gen hhdobmw = min(dobmh,dobmw)
drop if (rretmh-hhdobmh<720 | rretmw-hhdobmw<720 | lastintmh-hhdobmh<720 | lastintmw-hhdobmw<720 | deathmh-hhdobmh<720 | deathmw-hhdobmw<720)

/// generates censoring time and drops observations for which it is missing.

gen censtimeh = min(lastintmh,deathmh)-hhdobmh-720
gen censtimew = min(lastintmw,deathmw)-hhdobmw-720

drop if (censtimeh==. | censtimew==.)

/// keeps the variables that are important for the analysis

drop ageo lagageo ageh agew rretyrh rretyrw rretmonh rretmonw firstintyrh firstintyrw firstintyr firstintageh ///
	firstintagew lastintyrh lastintyrw lastintyr lastintageh lastintagew rretyrdif ///
	rretmondif agedifgroup interviewmonh interviewyrh rworkh rnotinlbrfh cohorth rpartlyreth rretiredh ///
	interviewmonw interviewyrw rworkw rnotinlbrfw rpartlyretw rretiredw rabmonthw rabyearw rabmonthh rabyearh ///
	cohortw interviewyr intmh intmw deathmoh deathmow deathyrh deathyrw
	
/// reshaping into long format
 	
gen financialwealthw = financialwealth
rename financialwealth financialwealthh
gen totalwealthw = totalwealth
rename totalwealth totalwealthh
gen agedifh = agedif
rename agedif agedifw
gen waveh = wave
rename wave wavew
gen sverygoodhealthh = rverygoodhealthw
gen sgoodhealthh = rgoodhealthw
gen spoorhealthh = rpoorhealthw
gen sverygoodhealthw = rverygoodhealthh
gen sgoodhealthw = rgoodhealthh
gen spoorhealthw = rpoorhealthh
gen spension1DCh = rpension1DCw
gen spension1DBh = rpension1DBw
gen spension1DCw = rpension1DCh
gen spension1DBw = rpension1DBh
gen shealthinsuranceh = rhealthinsurancew
gen shealthinsurancew = rhealthinsuranceh

reshape long rretm riearn agedif rretinsurance rprivateinsurance rpublicinsurance rhealthinsurance ranonhispanicwhite ///
	ranonhispanicblack rahispanic raotherrace racollegeabove rasomecollege rahighschoolged ralesshighschool ///
	rpension1DB rpension2DB rpension1DC rpension2DC rpension1DBDC rpension2DBDC shealthinsurance ///
	sverygoodhealth sgoodhealth spoorhealth spension1DC spension1DB ///
	lastintm hhdobm ///
	rverygoodhealth rgoodhealth rpoorhealth rtothealthexpen roophealthexpen rdiv_newen rdiv_midat rdiv_encen ///
	rdiv_wncen rdiv_satla rdiv_escen rdiv_wscen rdiv_mounta rdiv_pacifi rdiv_other ///
	rregion_northeast rregion_midwest rregion_south rregion_west ///
	rregion_other rjcocc dobm deathm financialwealth totalwealth wave censtime rretmondif, i(hh) j(husbandwife) string

gen gender = (husbandwife=="h")
drop husbandwife

gen censored = (rretm>=.)

gen failure = rretm-hhdobm-720
replace failure=censtime if censored==1

drop rretm deathm lastintm dobm

/// order variables to display hh | gender | dob | failure | censored | censtime | others...

order hh gender failure censored censtime

/// save hpdatamata, replace

summarize
sort censored
by censored: summarize


